@@ -560,7 +560,7 @@ $(document).ready(function() {
 
 	function zoek() {
 		var q = $searchTextInput.val();
-		window.location.hash = '#' + q;
+		window.location.hash = '#' + encodeURIComponent(q);
 		$.ajax({
 			url: 'search',
 			data: { q: q },
@@ -593,7 +593,7 @@ $(document).ready(function() {
 
 		var q = window.location.hash;
 		if(q)
-			q = q.substr(1);
+			q = decodeURIComponent(q.substr(1));
 		if(q) {
 			$searchTextInput.val(q);
 			zoek();
@@ -613,7 +613,7 @@ $(document).ready(function() {
 	$(window).bind('hashchange', function() {
 		var q = window.location.hash;
 		if(q)
-			q = q.substr(1);
+			q = decodeURIComponent(q.substr(1));
 		if(q == $searchTextInput.val())
 			return;
 		if(q) {
